@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -55,9 +55,7 @@ KNoteEditorConfigWidget::KNoteEditorConfigWidget(QWidget *parent)
     layout->setRowStretch(4, 1);
 }
 
-KNoteEditorConfigWidget::~KNoteEditorConfigWidget()
-{
-}
+KNoteEditorConfigWidget::~KNoteEditorConfigWidget() = default;
 
 void KNoteEditorConfigWidget::load(NoteShared::NoteDisplayAttribute *attr, bool isRichText)
 {
