@@ -21,7 +21,11 @@ public:
     Q_REQUIRED_RESULT QSize sizeHint() const override;
 
 protected:
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    void enterEvent(QEnterEvent *) override;
+#else
     void enterEvent(QEvent *) override;
+#endif
     void leaveEvent(QEvent *) override;
 
     void paintEvent(QPaintEvent *e) override;
